@@ -21,8 +21,8 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-#ifndef _GNOME_VFS_PRIVATE_UTILS_H
-#define _GNOME_VFS_PRIVATE_UTILS_H
+#ifndef GNOME_VFS_PRIVATE_UTILS_H
+#define GNOME_VFS_PRIVATE_UTILS_H
 
 /* You should not use calls in here outside GnomeVFS. The APIs in here may
  * break even when the GnomeVFS APIs are otherwise frozen.
@@ -33,7 +33,11 @@
 #include <libgnomevfs/gnome-vfs-process.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
-gchar   	*gnome_vfs_canonicalize_pathname         (char *path);
+G_BEGIN_DECLS
+
+gboolean	 _gnome_vfs_have_ipv6			 (void);
+
+gchar   	*_gnome_vfs_canonicalize_pathname         (char *path);
 GnomeVFSResult   gnome_vfs_remove_optional_escapes 	 (char *escaped_uri);
 
 pid_t	 	 gnome_vfs_forkexec 	(const gchar *file_name,
@@ -55,7 +59,6 @@ GnomeVFSResult	gnome_vfs_create_temp 	(const gchar *prefix,
 gboolean	gnome_vfs_atotm		(const gchar *time_string,
 					 time_t *value_return);
 
-/* Wrapper around gnome_i18n_get_language_list(). */
 GList	       *gnome_vfs_i18n_get_language_list
 					(const gchar *category_name);
 
@@ -65,9 +68,31 @@ GnomeVFSURI    *gnome_vfs_uri_new_private (const gchar *text_uri,
 					   gboolean allow_translate);
 
 
-gboolean	gnome_vfs_istr_has_prefix (const char *haystack,
+gboolean	_gnome_vfs_istr_has_prefix (const char *haystack,
 					   const char *needle);
-gboolean	gnome_vfs_istr_has_suffix (const char *haystack,
+gboolean	_gnome_vfs_istr_has_suffix (const char *haystack,
 					   const char *needle);
 
+GnomeVFSResult _gnome_vfs_uri_resolve_all_symlinks_uri (GnomeVFSURI *uri,
+							GnomeVFSURI **result_uri);
+GnomeVFSResult  _gnome_vfs_uri_resolve_all_symlinks (const char *text_uri,
+						     char **resolved_text_uri);
+
+gboolean  _gnome_vfs_uri_is_in_subdir (GnomeVFSURI *uri, GnomeVFSURI *dir);
+
+
+GnomeVFSResult _gnome_vfs_url_show_using_handler_with_env (const char   *url,
+                                                           char        **envp);
+gboolean       _gnome_vfs_use_handler_for_scheme          (const char   *scheme);
+
+gboolean       _gnome_vfs_prepend_terminal_to_vector      (int          *argc,
+							   char       ***argv);
+
+gboolean       _gnome_vfs_set_fd_flags                    (int           fd,
+                                                           int           flags);
+gboolean       _gnome_vfs_clear_fd_flags                  (int           fd,
+                                                           int           flags);
+
+G_END_DECLS
+
 #endif /* _GNOME_VFS_PRIVATE_UTILS_H */
